# Contributing

Contributions (from Atos SE employees only) are welcome, and they are greatly 
appreciated! Every little bit helps, and credit will always be given.

You can contribute in many ways:

## Types of Contributions

### Report Bugs

Report bugs at https://git.atosone.com/osiris/osiris/-/issues.

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

### Fix Bugs

Look through the Gitlab issues for bugs. Anything tagged with "bug" and "help
wanted" is open to whoever wants to implement it.

### Implement Features

Look through the Gitlab issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation

Code could always use more documentation, whether as part of the
official Code docs, in docstrings, and in 
https://https://git.atosone.com/osiris/osiris/-/wikis/home.

### Submit Feedback

The best way to send feedback is to file an issue at 
https://https://git.atosone.com/osiris/osiris/-/wikis/home.
If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.

## Get Started!

All the development documentation is available on 
https://git.atosone.com/osiris/osiris/-/wikis/home.

